==> vue-cli-plugin-stellar-3.0.2.tgz: package/generator/index.js <==
const fs = require('fs'),
  extendPluginOptions = require('../lib/extendPluginOptions')

const message = `
Documentation can be found at: https://quasar.dev

Quasar is relying on donations to evolve. We'd be very grateful
if you can read our manifest on "Why donations are important":
https://quasar.dev/why-donate
Donation campaign: https://donate.quasar.dev Any amount is very
welcomed. If invoices are required, please first contact
razvan@quasar.dev

Please give us a star on Github if you appreciate our work:
https://github.com/quasarframework/quasar

Enjoy! - Quasar Team
`

const iconMap = {
  ionicons: 'ionicons-v4',
  fontawesome: 'fontawesome-v5',
  mdi: 'mdi-v4'
}

const plugins = []

module.exports = (api, opts) => {
  const
    quasarPath = api.resolve('./src/plugins/qstellar.js'),
    tsPath = api.resolve('./src/main.ts'),
    jsPath = api.resolve('./src/main.js'),
    hasTS = fs.existsSync(tsPath)

  const dependencies = {
    qstellar: '^1.0.0',
    // '@quasar/extras': '^1.0.0'
  }

  const deps = {
    dependencies,
    devDependencies: {}
  }

  if (opts.quasar.cssPreprocessor === 'styl') {
    Object.assign(deps.devDependencies, {
      stylus: '^0.54.5',
      'stylus-loader': '^3.0.2'
    })
  }
  else if (['sass', 'scss'].includes(opts.quasar.cssPreprocessor)) {
    Object.assign(deps.devDependencies, {
      'node-sass': '^4.13.0',
      'sass-loader': '^8.0.0'
    })
  }

  if (opts.quasar.rtlSupport) {
    deps.devDependencies['postcss-rtl'] = '^1.2.3'
  }

  api.extendPackage(deps)

  // modify plugin options
  extendPluginOptions(api, (pluginOptions, transpileDependencies) => {
    pluginOptions.quasar = Object.assign(
      pluginOptions.quasar || {},
      {
        importStrategy: 'kebab',
        rtlSupport: opts.quasar.rtlSupport
      }
    )

    transpileDependencies.push('qstellar')

    return { pluginOptions, transpileDependencies }
  })

  api.render('./templates/common')

  if (opts.quasar.rtlSupport) {
    api.render('./templates/rtl')
  }

  if (opts.quasar.cssPreprocessor !== 'none') {
    api.render(`./templates/${opts.quasar.cssPreprocessor}`)
  }

  if (opts.quasar.replaceComponents) {
    const extension = hasTS ? 'ts' : 'js',
      routerFile = api.resolve(`src/router.${extension}`),
      hasRouter = fs.existsSync(routerFile)

    api.render(`./templates/with${hasRouter ? '' : 'out'}-router-base`, opts)
    api.render(
      `./templates/with${hasRouter ? '' : 'out'}-router`,
      opts
    )
    if (hasRouter) {
      api.render(`./templates/with-router-${extension}`)
    }
  }

  api.onCreateComplete(() => {
    let lines = `import Vue from 'vue'\n`

    const
      hasIconSet = opts.quasar.iconSet !== 'material-icons',
      hasLang = opts.quasar.lang !== 'en-us'

    if (!opts.quasar.features.includes(opts.quasar.iconSet)) {
      opts.quasar.features.push(opts.quasar.iconSet)
    }

    if (opts.quasar.cssPreprocessor !== 'none') {
      lines += `\nimport './styles/quasar.${opts.quasar.cssPreprocessor}'`
    }
    else {
      // lines += `\nimport 'qstellar/dist/quasar.css'`
      lines += `\nimport 'qstellar/dist/quasar.sass'`
    }

    if (opts.quasar.features.includes('ie')) {
      lines += `\nimport 'qstellar/dist/quasar.ie.polyfills'`
    }

    if (hasIconSet) {
      const set = iconMap[opts.quasar.iconSet] || opts.quasar.iconSet
      lines += `\nimport iconSet from 'qstellar/icon-set/${set}.js'`
    }

    if (hasLang) {
      lines += `\nimport lang from 'qstellar/lang/${opts.quasar.lang}.js'`
    }

    // opts.quasar.features
    //   .filter(feat => feat !== 'ie')
    //   .forEach(feat => {
    //     feat = iconMap[feat] || feat
    //     lines += `\nimport '@quasar/extras/${feat}/${feat}.css'`
    //   })

    // build import
    lines += `\nimport { Quasar } from 'qstellar'`

    // build Vue.use()
    lines += `\n\nVue.use(Quasar, {`
    lines += `\n  config: {}`

    lines += ',\n  plugins: {'
    plugins.forEach(part => {
      lines += `\n   ${part},`
    })
    lines += `\n  }`

    if (hasLang) {
      lines += `,\n  lang: lang`
    }
    if (hasIconSet) {
      lines += `,\n  iconSet: iconSet`
    }

    lines += `\n })`

    // Now inject additions to main.[js|ts]
    {
      const mainPath = fs.existsSync(tsPath) ? tsPath : jsPath
      let content = fs.readFileSync(mainPath, { encoding: 'utf8' })

      const mainLines = content.split(/\r?\n/g).reverse()

      const index = mainLines.findIndex(line => line.match(/^import/))
      mainLines[index] += `\nimport './plugins/qstellar'`

      content = mainLines.reverse().join('\n')
      fs.writeFileSync(mainPath, content, { encoding: 'utf8' })

      fs.writeFileSync(quasarPath, lines, { encoding: 'utf8' })
    }

    if (api.generator.hasPlugin('@vue/cli-plugin-eslint')) {
      const { spawnSync } = require('child_process')

      spawnSync('node', [
        'node_modules/@vue/cli-service/bin/vue-cli-service.js',
        'lint'
      ])
    }

    api.exitLog(message, 'info')
  })
}

==> vue-cli-plugin-stellar-3.0.4.tgz: package/generator/index.js <==
const fs = require('fs'),
  extendPluginOptions = require('../lib/extendPluginOptions')

const message = `
Documentation can be found at: https://quasar.dev

Quasar is relying on donations to evolve. We'd be very grateful
if you can read our manifest on "Why donations are important":
https://quasar.dev/why-donate
Donation campaign: https://donate.quasar.dev Any amount is very
welcomed. If invoices are required, please first contact
razvan@quasar.dev

Please give us a star on Github if you appreciate our work:
https://github.com/quasarframework/quasar

Enjoy! - Quasar Team
`

const iconMap = {
  ionicons: 'ionicons-v4',
  fontawesome: 'fontawesome-v5',
  mdi: 'mdi-v4'
}

const plugins = []

module.exports = (api, opts) => {
  const quasarPath = api.resolve('./src/plugins/qstellar.js'),
    tsPath = api.resolve('./src/main.ts'),
    jsPath = api.resolve('./src/main.js'),
    hasTS = fs.existsSync(tsPath)

  const dependencies = {
    qstellar: '^1.0.0'
    // '@quasar/extras': '^1.0.0'
  }

  const deps = {
    dependencies,
    devDependencies: {}
  }

  if (opts.quasar.cssPreprocessor === 'styl') {
    Object.assign(deps.devDependencies, {
      stylus: '^0.54.5',
      'stylus-loader': '^3.0.2'
    })
  } else if (['sass', 'scss'].includes(opts.quasar.cssPreprocessor)) {
    Object.assign(deps.devDependencies, {
      'node-sass': '^4.13.0',
      'sass-loader': '^8.0.0'
    })
  }

  if (opts.quasar.rtlSupport) {
    deps.devDependencies['postcss-rtl'] = '^1.2.3'
  }

  api.extendPackage(deps)

  // modify plugin options
  extendPluginOptions(api, (pluginOptions, transpileDependencies) => {
    pluginOptions.quasar = Object.assign(pluginOptions.quasar || {}, {
      importStrategy: 'kebab',
      rtlSupport: opts.quasar.rtlSupport
    })

    transpileDependencies.push('qstellar')

    return { pluginOptions, transpileDependencies }
  })

  // api.render('./templates/common')

  if (opts.quasar.rtlSupport) {
    api.render('./templates/rtl')
  }

  if (opts.quasar.cssPreprocessor !== 'none') {
    api.render(`./templates/${opts.quasar.cssPreprocessor}`)
  }

  if (opts.quasar.replaceComponents) {
    const extension = hasTS ? 'ts' : 'js',
      routerFile = api.resolve(`src/router.${extension}`),
      hasRouter = fs.existsSync(routerFile)

    api.render(`./templates/with${hasRouter ? '' : 'out'}-router-base`, opts)
    api.render(`./templates/with${hasRouter ? '' : 'out'}-router`, opts)
    if (hasRouter) {
      api.render(`./templates/with-router-${extension}`)
    }
  }

  api.onCreateComplete(() => {
    let lines = `import Vue from 'vue'\n`

    const hasIconSet = opts.quasar.iconSet !== 'material-icons',
      hasLang = opts.quasar.lang !== 'en-us'

    if (!opts.quasar.features.includes(opts.quasar.iconSet)) {
      opts.quasar.features.push(opts.quasar.iconSet)
    }

    if (opts.quasar.cssPreprocessor !== 'none') {
      lines += `\nimport './styles/quasar.${opts.quasar.cssPreprocessor}'`
    } else {
      // lines += `\nimport 'qstellar/dist/quasar.css'`
      lines += `\nimport 'qstellar/dist/quasar.min.css'`
    }

    if (opts.quasar.features.includes('ie')) {
      lines += `\nimport 'qstellar/dist/quasar.ie.polyfills'`
    }

    if (hasIconSet) {
      const set = iconMap[opts.quasar.iconSet] || opts.quasar.iconSet
      lines += `\nimport iconSet from 'qstellar/icon-set/${set}.js'`
    }

    if (hasLang) {
      lines += `\nimport lang from 'qstellar/lang/${opts.quasar.lang}.js'`
    }

    // opts.quasar.features
    //   .filter(feat => feat !== 'ie')
    //   .forEach(feat => {
    //     feat = iconMap[feat] || feat
    //     lines += `\nimport '@quasar/extras/${feat}/${feat}.css'`
    //   })

    // build import
    lines += `\nimport { Quasar } from 'qstellar'`

    // build Vue.use()
    lines += `\n\nVue.use(Quasar, {`
    lines += `\n  config: {}`

    lines += ',\n  plugins: {'
    plugins.forEach((part) => {
      lines += `\n   ${part},`
    })
    lines += `\n  }`

    if (hasLang) {
      lines += `,\n  lang: lang`
    }
    if (hasIconSet) {
      lines += `,\n  iconSet: iconSet`
    }

    lines += `\n })`

    // Now inject additions to main.[js|ts]
    {
      const mainPath = fs.existsSync(tsPath) ? tsPath : jsPath
      let content = fs.readFileSync(mainPath, { encoding: 'utf8' })

      const mainLines = content.split(/\r?\n/g).reverse()

      const index = mainLines.findIndex((line) => line.match(/^import/))
      mainLines[index] += `\nimport './plugins/qstellar'`

      content = mainLines.reverse().join('\n')
      fs.writeFileSync(mainPath, content, { encoding: 'utf8' })

      fs.writeFileSync(quasarPath, lines, { encoding: 'utf8' })
    }

    if (api.generator.hasPlugin('@vue/cli-plugin-eslint')) {
      const { spawnSync } = require('child_process')

      spawnSync('node', [
        'node_modules/@vue/cli-service/bin/vue-cli-service.js',
        'lint'
      ])
    }

    api.exitLog(message, 'info')
  })
}
